--[[           ]]
--[[ Libraries ]]
--[[           ]]

local L                 = AceLibrary("AceLocale-2.2"):new("Vibrant")


--[[          ]]
--[[ Defaults ]]
--[[          ]]

local defaults = 
{
	ShowUI			= true,
	ButtonDistance	= 128,
	ButtonSize		= 64,
	ReplaySpeed		= 1,
	SequenceAutoDelete	= false,
	InitialPause	= 0.25,
	Pause			= 1.25,
	Glowtime		= 2.25,
	SoundWhenClick	= true,
	SoundWhenPlay	= true,
	ClickSound		= "Sound\\interface\\PickUp\\PickUpGems.wav",
	PlaySound		= "Sound\\interface\\PickUp\\PutDownGems.wav",

}


--[[      ]]
--[[ Menu ]]
--[[      ]]

local menu = {
	type = 'group',
	args = {
		uitoggle = {
			type	= 'toggle',
			name	= L["ShowUI"],
			desc	= L["ShowUIDesc"],
			get		= function(u) return Vibrant.db.profile.ShowUI end,
			set		= function(u) Vibrant.db.profile.ShowUI = not Vibrant.db.profile.ShowUI; Vibrant:CheckVisibility(); end,
			order	= 1,
		},

		distance = {
			type	= 'range',
			name	= L["ButtonDistance"],
			desc	= L["ButtonDistanceDesc"],
			get		= function(v) return Vibrant.db.profile.ButtonDistance end,
			set		= function(v) Vibrant.db.profile.ButtonDistance = v; Vibrant:UpdateFrame(); end,
			min		= 64,
			max		= 256,
			step	= 4,
			isPercent	= false,
			order	= 2,
		},
		
		size = {
			type	= 'range',
			name	= L["ButtonSize"],
			desc	= L["ButtonSizeDesc"],
			get		= function(v) return Vibrant.db.profile.ButtonSize end,
			set		= function(v) Vibrant.db.profile.ButtonSize = v; Vibrant:UpdateFrame(); end,
			min		= 32,
			max		= 128,
			step	= 4,
			isPercent	= false,
			order	= 3,
		},
		
		clicksound = {
			type	= 'toggle',
			name	= L["SoundWhenClick"],
			desc	= L["SoundWhenClickDesc"],
			get		= function(u) return Vibrant.db.profile.SoundWhenClick end,
			set		= function(u) Vibrant.db.profile.SoundWhenClick = not Vibrant.db.profile.SoundWhenClick; end,
			order	= 4,
		},
		
		playsound = {
			type	= 'toggle',
			name	= L["SoundWhenPlay"],
			desc	= L["SoundWhenPlayDesc"],
			get		= function(u) return Vibrant.db.profile.SoundWhenPlay end,
			set		= function(u) Vibrant.db.profile.SoundWhenPlay = not Vibrant.db.profile.SoundWhenPlay; end,
			order	= 4,
		},

	}
}

	
--[[             ]]
--[[ ACE2 Part 2 ]]
--[[             ]]

Vibrant = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceDB-2.0", "AceConsole-2.0", "AceDebug-2.0", "FuBarPlugin-2.0")


--[[                   ]]
--[[ ACE2 Menu Options ]]
--[[                   ]]

Vibrant.OnMenuRequest = menu
Vibrant.name = L["Vibrant"]
Vibrant.hasIcon = "Interface\\AddOns\\Vibrant\\icon_off"
Vibrant.defaultMinimapPosition = 40
Vibrant.cannotDetachTooltip = true
Vibrant.independentProfile = true
Vibrant.defaultPosition = "LEFT"
Vibrant.hideWithoutStandby = true
Vibrant.hasNoColor = true


--[[                ]]
--[[ OnInitialize() ]]
--[[                ]]

function Vibrant:OnInitialize()
	self:RegisterDB("VibrantDB")
	self:RegisterDefaults('profile', defaults )
	self:RegisterChatCommand( {L["/Vibrant"]}, menu )
	if not FuBar then
		self.OnMenuRequest.args.hide.guiName = "Hide minimap icon"
		self.OnMenuRequest.args.hide.desc = "Hide minimap icon"
	end
	self:Print("Loaded successfully.")
end

--[[            ]]
--[[ OnEnable() ]]
--[[            ]]

function Vibrant:OnEnable()
	-- Build our gui
	self:BuildDisplay()
	-- Check frame visibility, show if necessary
	self:CheckVisibility()
end

--[[             ]]
--[[ OnDisable() ]]
--[[             ]]

function Vibrant:OnDisable()
	self:HideGUI()
end

--[[           ]]
--[[ OnClick() ]]
--[[           ]]

function Vibrant:OnClick()
	Vibrant.db.profile.ShowUI = not Vibrant.db.profile.ShowUI
	PlaySoundFile(Vibrant.db.profile.ClickSound);
	
	if Vibrant.db.profile.ShowUI then
		Vibrant:ShowGUI()
--~ 		Vibrant:Print("Showing UI.")
	else
		Vibrant:HideGUI()
--~ 		Vibrant:Print("Hiding UI.")
	end
end

